@@ -1,14 +1,15 @@
 C
-C  This file is part of MUMPS 5.3.3, released
-C  on Mon Jun 15 09:57:25 UTC 2020
+C  This file is part of MUMPS 5.4.1, released
+C  on Tue Aug  3 09:49:43 UTC 2021
 C
 C
-C  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+C  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
 C  Mumps Technologies, University of Bordeaux.
 C
 C  This version of MUMPS is provided to you free of charge. It is
-C  released under the CeCILL-C license:
-C  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html
+C  released under the CeCILL-C license 
+C  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
+C  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
 C
 C
 C     Common header positions:
@@ -26,6 +27,7 @@ C                                           2=LowRank factors/panels only
 C                                           3=LowRank CB+factor/panel)
 C     XXEBF  ->  End of Blocfacto (0=not yet, 1=finished)  
 C     XXD    ->  dynamic data size
+C     XXG    ->  GPU information (currently number of pinned rows NFRONT-NBROWS_CPU)
 C REMARK: .h file could be replaced by a module with functions to get node status
 C          added in the module.
 C 
@@ -35,6 +37,7 @@ C
       INTEGER, PARAMETER :: XXNBPR = 9
       INTEGER, PARAMETER :: XXEBF = 10
       INTEGER, PARAMETER :: XXD = 11
+      INTEGER, PARAMETER :: XXG = 13
 C 
 C     Size of header in incore and out-of-core
 C
@@ -43,8 +46,8 @@ C
 C     At the moment, all headers are of the same size because
 C     no OOC specific information are stored in header.
 CM     other OOC specific information directly in the headers.
-      PARAMETER (XSIZE_IC=13,XSIZE_OOC_SYM=13,XSIZE_OOC_UNSYM=13,
-     &           XSIZE_OOC_NOPANEL=13)
+      PARAMETER (XSIZE_IC=14,XSIZE_OOC_SYM=14,XSIZE_OOC_UNSYM=14,
+     &           XSIZE_OOC_NOPANEL=14)
 C
 C     -------------------------------------------------------
 C     Position of header size (formerly XSIZE) in KEEP array.
