@@ -1,15 +1,16 @@
 /*
  *
- *  This file is part of MUMPS 5.3.3, released
- *  on Mon Jun 15 09:57:25 UTC 2020
+ *  This file is part of MUMPS 5.4.1, released
+ *  on Tue Aug  3 09:49:43 UTC 2021
  *
  *
- *  Copyright 1991-2020 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Copyright 1991-2021 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
  *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
- *  released under the CeCILL-C license:
- *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html
+ *  released under the CeCILL-C license 
+ *  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
+ *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
  *
  */
 #include "mumps_io.h"
@@ -23,18 +24,73 @@
 double mumps_time_spent_in_sync;
 #endif
 double read_op_vol,write_op_vol,total_vol;
-/**
- * Forward declaration. Definition at the end of the file.
- */
-/*MUMPS_INLINE int
-  mumps_convert_2fint_to_longlong( MUMPS_INT *, MUMPS_INT *, long long *);*/
+void MUMPS_CALL MUMPS_DUMPRHSBINARY_C ( MUMPS_INT *N, MUMPS_INT *NRHS,
+     MUMPS_INT *LRHS, float *RHS, MUMPS_INT *K35,
+     char *filename, mumps_ftnlen l1 )
+{
+   float *RHSshift; /* float: arbitrary, we use binary content */
+   FILE *fd;
+   int icol;
+   fd=fopen(filename, "w");
+   RHSshift=RHS;
+   for(icol=0;icol<*NRHS;icol++)
+   {
+     fwrite(RHSshift, (size_t)(*K35), (size_t)(*N), fd);
+     RHSshift=RHSshift+(size_t)(*LRHS)*(size_t)(*K35/sizeof(float));
+   }
+   fclose(fd);
+}
+void MUMPS_CALL MUMPS_DUMPMATBINARY_C ( MUMPS_INT *N, MUMPS_INT8 *NNZ,
+     MUMPS_INT* K35, MUMPS_INT *irn, MUMPS_INT *jcn,
+     void *A, MUMPS_INT *is_A_provided,
+     char *filename, mumps_ftnlen l1 )
+{
+   int64_t i8;
+   int32_t myN, tmpi;
+   FILE *fd;
+   fd=fopen(filename, "w");
+   /* cast to int32_t in case MUMPS_INT is 64-bits */
+   myN=(int32_t)(*N);
+   fwrite( &myN, sizeof(int32_t), 1, fd);
+   fwrite( NNZ, sizeof(int64_t), 1, fd);
+   if (*NNZ > 0)
+   {
+     if ( sizeof(MUMPS_INT) == 4 )
+     {
+       /* write irn and jcn contents directly */
+       fwrite( irn, sizeof(int32_t), (size_t)(*NNZ), fd);
+       fwrite( jcn, sizeof(int32_t), (size_t)(*NNZ), fd);
+     }
+     else
+     {
+       for(i8=0;i8 < *NNZ;i8++)
+       {
+          tmpi=irn[i8];
+          fwrite(&tmpi, sizeof(int32_t), 1, fd);
+       }
+       for(i8=0;i8 < *NNZ;i8++)
+       {
+          tmpi=jcn[i8];
+          fwrite(&tmpi, sizeof(int32_t), 1, fd);
+       }
+     }
+     if (*is_A_provided)
+     {
+       fwrite(A, (size_t)(*K35), (size_t)(*NNZ), fd);
+     }
+   }
+   fclose(fd);
+}
 /* Tests if the request "request_id" has finished. It sets the flag  */
 /* argument to 1 if the request has finished (0 otherwise)           */
 void MUMPS_CALL
 MUMPS_TEST_REQUEST_C(MUMPS_INT *request_id,MUMPS_INT *flag,MUMPS_INT *ierr)
 {
   char buf[64]; /* for error message */
-  MUMPS_INT request_id_loc,flag_loc;
+  MUMPS_INT request_id_loc;
+#if ! defined(MUMPS_WIN32) && ! defined(WITHOUT_PTHREAD)
+  MUMPS_INT flag_loc;
+#endif
 #if ! defined(MUMPS_WIN32)
   struct timeval start_time,end_time;
   gettimeofday(&start_time,NULL);
@@ -57,7 +113,7 @@ MUMPS_TEST_REQUEST_C(MUMPS_INT *request_id,MUMPS_INT *flag,MUMPS_INT *ierr)
 #endif
   default:
     *ierr=-92;
-    sprintf(buf,"Error: unknown I/O strategy : %d\n",mumps_io_flag_async);
+    sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)mumps_io_flag_async);
     mumps_io_error((MUMPS_INT)*ierr,buf);
     return;
   }
@@ -91,7 +147,7 @@ MUMPS_WAIT_REQUEST(MUMPS_INT *request_id,MUMPS_INT *ierr)
 #endif
   default:
     *ierr=-92;
-    sprintf(buf,"Error: unknown I/O strategy : %d\n",mumps_io_flag_async);
+    sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)mumps_io_flag_async);
     mumps_io_error((MUMPS_INT)*ierr,buf);
     return;
     /*    printf("Error: unknown I/O strategy : %d\n",mumps_io_flag_async);
@@ -146,7 +202,10 @@ MUMPS_LOW_LEVEL_INIT_OOC_C(MUMPS_INT *_myid, MUMPS_INT *total_size_io, MUMPS_INT
                            MUMPS_INT *flag_tab, MUMPS_INT *ierr)
 {
   char buf[128]; /* for error message */
-  MUMPS_INT myid_loc,async_loc,ierr_loc,size_element_loc,nb_file_type_loc,*flag_tab_loc;
+  MUMPS_INT myid_loc,async_loc,size_element_loc,nb_file_type_loc,*flag_tab_loc;
+#if ! defined(MUMPS_WIN32) && ! defined(WITHOUT_PTHREAD)
+  MUMPS_INT ierr_loc;
+#endif
   long long total_size_io_loc;
   MUMPS_INT i;
   myid_loc=(MUMPS_INT)*_myid;
@@ -213,7 +272,7 @@ MUMPS_LOW_LEVEL_INIT_OOC_C(MUMPS_INT *_myid, MUMPS_INT *total_size_io, MUMPS_INT
   if(async_loc){
     switch(async_loc){
     case IO_SYNC:
-      printf("mumps_low_level_init_ooc_c should not be called with strategy %d\n",mumps_io_flag_async);
+      printf("mumps_low_level_init_ooc_c should not be called with strategy %d\n",(int)mumps_io_flag_async);
       break;
 #if ! defined(MUMPS_WIN32) && ! defined(WITHOUT_PTHREAD)
     case IO_ASYNC_TH:
@@ -226,7 +285,7 @@ MUMPS_LOW_LEVEL_INIT_OOC_C(MUMPS_INT *_myid, MUMPS_INT *total_size_io, MUMPS_INT
 #endif
     default:
       *ierr=-92;
-      sprintf(buf,"Error: unknown I/O strategy : %d\n",(MUMPS_INT)*async);
+      sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)*async);
       mumps_io_error((MUMPS_INT)*ierr,buf);
       return;
     }
@@ -283,7 +342,7 @@ MUMPS_LOW_LEVEL_WRITE_OOC_C(const MUMPS_INT * strat_IO,
 #endif
     default:
       *ierr=-91;
-      sprintf(buf,"Error: unknown I/O strategy : %d\n",(MUMPS_INT)*strat_IO);
+      sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)*strat_IO);
       mumps_io_error((MUMPS_INT)*ierr,buf);
       return;
     }
@@ -341,7 +400,7 @@ MUMPS_LOW_LEVEL_READ_OOC_C(const MUMPS_INT * strat_IO,
 #endif
       default:
         *ierr=-91;
-        sprintf(buf,"Error: unknown I/O strategy : %d\n",(MUMPS_INT)*strat_IO);
+        sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)*strat_IO);
         mumps_io_error((MUMPS_INT)*ierr,buf);
         return;
       }
@@ -421,7 +480,7 @@ MUMPS_CLEAN_IO_DATA_C(MUMPS_INT *myid,MUMPS_INT *step,MUMPS_INT *ierr)
 #endif
   default:
     *ierr=-91;
-    sprintf(buf,"Error: unknown I/O strategy : %d\n",mumps_io_flag_async);
+    sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)mumps_io_flag_async);
     mumps_io_error((MUMPS_INT)*ierr,buf);
     return;
   }
@@ -433,12 +492,12 @@ void MUMPS_CALL
 MUMPS_OOC_PRINT_STATS()
 {
 #if ! defined(MUMPS_WIN32)
-  printf("%d: total time spent in i/o mode = %lf\n",mumps_io_myid,mumps_time_spent_in_sync);
+  printf("%d: total time spent in i/o mode = %lf\n",(int)mumps_io_myid,mumps_time_spent_in_sync);
 #endif
-  printf("%d: Volume of read i/o = %lf\n",mumps_io_myid,read_op_vol);
-  printf("%d: Volume of write i/o = %lf\n",mumps_io_myid,write_op_vol);
+  printf("%d: Volume of read i/o = %lf\n",(int)mumps_io_myid,read_op_vol);
+  printf("%d: Volume of write i/o = %lf\n",(int)mumps_io_myid,write_op_vol);
   total_vol=total_vol+read_op_vol+write_op_vol;
-  printf("%d: Total i/o volume = %lf\n",mumps_io_myid,total_vol);
+  printf("%d: Total i/o volume = %lf\n",(int)mumps_io_myid,total_vol);
   return;
 }
 void MUMPS_CALL
@@ -457,7 +516,7 @@ MUMPS_GET_MAX_NB_REQ_C(MUMPS_INT *max,MUMPS_INT *ierr)
 #endif
   default:
     *ierr=-91;
-    sprintf(buf,"Error: unknown I/O strategy : %d\n",mumps_io_flag_async);
+    sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)mumps_io_flag_async);
     mumps_io_error((MUMPS_INT)*ierr,buf);
     return;
   }
@@ -558,7 +617,7 @@ MUMPS_OOC_START_LOW_LEVEL(MUMPS_INT *ierr)
 #endif
     default:
       *ierr=-91;
-      sprintf(buf,"Error: unknown I/O strategy : %d\n",mumps_io_flag_async);
+      sprintf(buf,"Error: unknown I/O strategy : %d\n",(int)mumps_io_flag_async);
       mumps_io_error((MUMPS_INT)*ierr,buf);
       return;
     }
